package de.geodbs;
/**
 * Beispielprogramm zum Zugriff auf Oracle Spatial ber die API oracle.spatial.
 *
 * @author: Thomas Brinkhoff, https://www.geodbs.de/
 * @version: 4. Auflage, Abs. 9.3.2.3
 */

import static de.geodbs.ConnectionParametersOra.*;

import java.sql.*;		// JDBC-Klassen

import oracle.spatial.geometry.JGeometry;		// aus sdoapi.jar


public class OraSpatialJGeometryExample {

public static void main (String[] args) {

	try (Connection db = DriverManager.getConnection(url, user, pw);
	     Statement statement = db.createStatement();) {
		// 1. Anfrage ausfhren
		int srid = 0;
		String sql = "SELECT * FROM GeoGemeinden WHERE code = 'DE03403000'";
		ResultSet result = statement.executeQuery(sql);
		if (result.next()) {
			System.out.print(result.getString("name") + " - ");    // name
			// Zugriff auf Punktgeometrie
			Struct struct = (Struct) result.getObject("geom");
			JGeometry jGeom = JGeometry.loadJS(struct);
			System.out.println("Dimension: " + jGeom.getDimensions());
			System.out.println("Type: " + jGeom.getType());
			srid = jGeom.getSRID();
			System.out.println("SRID: " + srid);
			// Umwandlung in AWT-Point2D
			java.awt.geom.Point2D centrum = jGeom.getJavaPoint();
			System.out.println(centrum.getX() + " / " + centrum.getY());
			System.out.println();
		}
		result.close();
		
		// 2. Anfrage auf Flchen ausfhren:
		sql = "SELECT * FROM Ortsnetze WHERE vorwahl = '0441'";
		result = statement.executeQuery(sql);
		if (result.next()) {
			// Attribut "gebiet"
			Struct struct = (Struct) result.getObject("gebiet");
			JGeometry jGeom = JGeometry.loadJS(struct);
			System.out.println("Type: " + jGeom.getType());
			System.out.println("Kreis? " + jGeom.isCircle());
			System.out.println("#Punkte: " + jGeom.getNumPoints());
			double mbr[] = jGeom.getMBR();
			System.out.print("MUR: ");
			for (double mbrOrd : mbr)
				System.out.print(mbrOrd + " ");
			System.out.println();
			int elemInfo[] = jGeom.getElemInfo();
			System.out.print("ElemInfo: ");
			for (int elem : elemInfo)
				System.out.print(elem + " ");
			System.out.println();
			double ord[] = jGeom.getOrdinatesArray();
			System.out.println("coordinates: ");
			for (int i=0; i<ord.length/2; i++)
				System.out.print("(" + ord[2*i] + " , " + ord[2*i+1] + ") ");
			System.out.println();
			// Umwandlung in AWT-Shape
			java.awt.Shape shape = jGeom.createShape();
			System.out.println("Shape: " + shape.getClass().getName());
		}
		result.close();
		
		// Punktgeometrie ndern:
		sql = "UPDATE GeoGemeinden SET geom=? WHERE name = 'Helgoland'";
		try ( PreparedStatement update = db.prepareStatement(sql) ) {
		  // Punktgeometrie setzen und ndern
		    JGeometry centrum = new JGeometry(7.887148,54.181562, srid);
		    update.setObject (1,JGeometry.storeJS(centrum,db));
		    update.executeUpdate();
		}
	} // try

	// Fehlerbehandlung:
	catch (Exception ex) {
		System.err.println("Fehler beim Datenbankzugriff: "+ex);
		ex.printStackTrace();
	}

}
	
}
