package de.geodbs;
/**
 * Beispielprogramm zum Zugriff auf Oracle Spatial mit Shapefiles.
 *
 * @author: Thomas Brinkhoff, https://www.geodbs.de/
 * @version: Auflage 4, Abs. 9.3.2.4
 */

import static de.geodbs.ConnectionParametersOra.*;

import java.sql.*;		// JDBC-Klassen

import oracle.spatial.geometry.JGeometry;		// aus sdoapi.jar
import oracle.spatial.util.ShapefileReaderJGeom;		// aus sdoutl.jar

public class OraSpatialShapefileExample {


public static void main (String[] args) {
	// Verbindung zur Datenbank aufbauen
	try (Connection db = DriverManager.getConnection(url, user, pw)) {
		// Update vorbereiten
		String sql = "UPDATE GeoGemeinden SET geom = ? WHERE name = 'Helgoland'";
		PreparedStatement update = db.prepareStatement(sql);
		// Shapefile ffnen
		ShapefileReaderJGeom reader = new ShapefileReaderJGeom("C:\\Temp\\Helgoland.shp");
		// Alle Geometrien umwandeln und abspeichern
		for (int i=0; i<reader.numRecords(); i++) {
			byte[] data = reader.getGeometryBytes(i);
			JGeometry geom = ShapefileReaderJGeom.getGeometry(data,4326);
			update.setObject (1,JGeometry.storeJS(geom,db));
			update.executeUpdate();
		}
		// Schlieen
		reader.closeShapefile();
		update.close();
	} // try

	// Fehlerbehandlung:
	catch (Exception ex) {
		System.err.println("Fehler beim Datenbankzugriff: "+ex);
		ex.printStackTrace();
	}
}

}
