package de.geodbs;
/**
 * Beispielprogramm, um die Topology "GeoDbLandTP" mit Daten zu ergnzen.
 * 
 * @author: Thomas Brinkhoff, https://www.geodbs.de/
 * @version: 4. Auflage, Abs. 10.5.2.4
 */

import static de.geodbs.ConnectionParametersOra.*;

import java.sql.*;		// JDBC-Klassen

import oracle.spatial.geometry.JGeometry;  // aus sdoapi.jar
import oracle.spatial.topo.TopoMap;        // aus sdotopo.jar, bentigt sdoutl.jar


public class OraTopologyExample {

	public static void main (String[] args) {
		// Verbindung zur Datenbank aufbauen
		try (Connection db = DriverManager.getConnection(url, user, pw)) {
			// TopoMap fr 100 Kanten und Knoten und 10 Maschen erzeugen
			TopoMap topo = new TopoMap(db,"GeoDbLandTP",100,100,10);
			// und in DB-Puffer mit Schreibberechtigung laden
			topo.loadWindow(0.0,0.0,20.0,20.0,true);
			// Geometrie fr Weideland bestimmen und der TopoMap hinzufgen
			int[][] topPrims = new int[2][];    // Speicherung der Maschen-IDs
			Statement stmt = db.createStatement();
			ResultSet res = stmt.executeQuery(
				"SELECT SDO_GEOM.SDO_DIFFERENCE(SDO_UTIL.EXTRACT(g1.geo,2),g2.geo,0.001) " +
				"FROM GeoDbLand g1, GeoDbLand g2 WHERE g1.name = 'Land' AND g2.name = 'Haus'");
			res.next();
			JGeometry geo = JGeometry.loadJS((Struct) res.getObject(1));
			System.out.println(geo.getType());
			topPrims[0] = topo.addPolygonGeometry(geo);
			
			// Geometrie fr Bebauung bestimmen und der TopoMap hinzufgen
			res = stmt.executeQuery("SELECT geo FROM GeoDbLand WHERE name = 'Haus'");
			res.next();
			geo = JGeometry.loadJS((Struct) res.getObject(1));
			topPrims[1] = topo.addPolygonGeometry(geo);
			// Topologie-Commit
			topo.commitDB();
			// ID der topologischen Ebene bestimmen
			res = stmt.executeQuery("SELECT tg_layer_id FROM USER_SDO_TOPO_METADATA WHERE table_name = 'GEODBLANDNUTZUNG'");
			if (! res.next())
				throw new SQLException("Keine Layer-ID!");
			int layerId = res.getInt("tg_layer_id");
			// Topologieobjekte in GeoDbLandNutzung einfgen
			String nutz[] = new String[] {"Weideland","Bebauung"};
			for (int j=0; j<2; j++) {
				String insert = "INSERT INTO GeoDbLandNutzung VALUES ("+(10+j)+",'"+nutz[j]+"',"+
                   "SDO_TOPO_GEOMETRY('GeoDbLandTP',3,"+layerId+",SDO_TOPO_OBJECT_ARRAY (";
				// fr jede Masche ein SDO_TOPO_OBJECT hinzufgen
				for (int i=0; i<topPrims[j].length; i++) {
					insert += "SDO_TOPO_OBJECT("+topPrims[j][i]+",3)";
					if (i < topPrims[j].length-1)
						insert += ",";
				}
				insert += ")))";
				System.out.println(insert);
				stmt.executeQuery(insert);
			}
			// Anweisung schlieen
			stmt.close();
		}
		// Fehlerbehandlung:
		catch (Exception ex) {
			System.err.println("Fehler: " + ex);
			ex.printStackTrace();
		}
	}
	
}
