package de.geodbs;
/**
 * Beispielprogramm zum Zugriff auf Oracle Spatial ber WKT und WKB mit Untersttzung von JTS.
 *
 * @author: Thomas Brinkhoff, https://www.geodbs.de/
 * @version: Auflage 4, Abs. 9.3.2.1
 */

import static de.geodbs.ConnectionParametersOra.*;

import java.sql.*;		// JDBC-Klassen

import org.locationtech.jts.geom.Geometry;		// JTS-Klassen
import org.locationtech.jts.io.ParseException;
import org.locationtech.jts.io.WKBReader;


public class OraWktWkbExample {

public static void main (String[] args) {
	// Verbindung zur Datenbank aufbauen
	try (Connection db = DriverManager.getConnection(url, user, pw)) {
		// Rumliche Selektion ausfhren
		String queryWKT = "POLYGON((5 5,5 15,15 15,15 5,5 5))";
		String sql = "SELECT name, g.geo.GET_WKT() AS wkt FROM GeoDbLand g WHERE SDO_ANYINTERACT(geo,SDO_GEOMETRY('"+
				queryWKT+"')) = 'TRUE'";
		System.out.println(sql);
		try (Statement statement = db.createStatement();
		     ResultSet result = statement.executeQuery(sql)) {
			while (result.next()) {
				System.out.print(result.getString("name") + " - ");
				// Zugriff auf Geometrie als WKT-Zeichenkette: 
				System.out.println(result.getString("wkt"));
			}
		}
		System.out.println();

		// Rumliche Selektion ausfhren
		queryWKT = "POLYGON((5 5,5 15,15 15,15 5,5 5))";
		sql = "SELECT name, g.geo.GET_WKB() AS wkb FROM GeoDbLand g WHERE SDO_ANYINTERACT(geo,SDO_GEOMETRY('"+
				queryWKT+"')) = 'TRUE'";
		System.out.println(sql);
		WKBReader wkbReader = new WKBReader();
		try (Statement statement = db.createStatement();
		     ResultSet result = statement.executeQuery(sql)) {
			while (result.next()) {
				System.out.print(result.getString("name") + " - ");
				// Zugriff auf Geometrie als WBT:
				byte[] wkb = result.getBytes("wkb");
				Geometry geom = wkbReader.read(wkb);
				System.out.println(geom.getArea()+" - "+geom.toText());
			}
		} catch (ParseException e) {
			e.printStackTrace();
		}
		System.out.println();
	} // try
	catch (SQLException ex) {
		System.err.println("Fehler beim Datenbankzugriff: "+ex);
	}
}

}
